==> func_adl_servicex_xaodr21-2.2.0.21.2.283-py3-none-any.whl: func_adl_servicex_xaodr21/ROOT/Fit/datarange.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr21

_method_map = {
    'NDim': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::Fit::DataRange',
        'method_name': 'NDim',
        'return_type': 'unsigned int',
    },
    'Size': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::Fit::DataRange',
        'method_name': 'Size',
        'return_type': 'unsigned int',
    },
    'IsSet': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::Fit::DataRange',
        'method_name': 'IsSet',
        'return_type': 'bool',
    },
    'IsInside': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::Fit::DataRange',
        'method_name': 'IsInside',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])


        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class DataRange:
    "A class"


    def NDim(self) -> int:
        "A method"
        ...

    def Size(self, icoord: int) -> int:
        "A method"
        ...

    def IsSet(self) -> bool:
        "A method"
        ...

    def IsInside(self, x: float, icoord: int) -> bool:
        "A method"
        ...

==> func_adl_servicex_xaodr21-2.3.0.21.2.283-py3-none-any.whl: func_adl_servicex_xaodr21/ROOT/Fit/datarange.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr21

_method_map = {
    'NDim': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::Fit::DataRange',
        'method_name': 'NDim',
        'return_type': 'unsigned int',
    },
    'Size': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::Fit::DataRange',
        'method_name': 'Size',
        'return_type': 'unsigned int',
    },
    'IsSet': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::Fit::DataRange',
        'method_name': 'IsSet',
        'return_type': 'bool',
    },
    'IsInside': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'ROOT::Fit::DataRange',
        'method_name': 'IsInside',
        'return_type': 'bool',
    },
}

_enum_function_map = {      
}

_defined_enums = {      
}

_object_cpp_as_py_namespace="ROOT.Fit"

T = TypeVar('T')

def add_enum_info(s: ObjectStream[T], enum_name: str) -> ObjectStream[T]:
    '''Use this to add enum definition information to the backend.

    This can be used when you are writing a C++ function that needs to
    make sure a particular enum is defined.

    Args:
        s (ObjectStream[T]): The ObjectStream that is being updated
        enum_name (str): Name of the enum

    Raises:
        ValueError: If it is not known, a list of possibles is printed out

    Returns:
        ObjectStream[T]: Updated object stream with new metadata.
    '''
    if enum_name not in _defined_enums:
        raise ValueError(f"Enum {enum_name} is not known - "
                            f"choose from one of {','.join(_defined_enums.keys())}")
    return s.MetaData(_defined_enums[enum_name])

def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])


        for md in _enum_function_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class DataRange:
    "A class"


    def NDim(self) -> int:
        "A method"
        ...

    def Size(self, icoord: int) -> int:
        "A method"
        ...

    def IsSet(self) -> bool:
        "A method"
        ...

    def IsInside(self, x: float, icoord: int) -> bool:
        "A method"
        ...
